<?php

/**
 * @package: patterns
 * @author: Yevhen Odynets
 * @date: 2025-07-08
 * @time: 11:14
 */

declare(strict_types = 1);

namespace Pattern\Creational\AbstractFactory;

readonly class ParcelSender
{
    private AbstractFactoryInterface $service;

    public function __construct(
        private ProvidersEnum $provider,
        private string $destinationAddress,
    ) {
        $this->service = DeliveryServiceFactory::create($this->provider);
    }

    public function send(): bool
    {
        // getting the delivery service
        $deliveryService = $this->service->createDeliveryService();

        // getting the parcel
        $parcel = $this->service->createParcel();

        // setting up address & checking the parcel
        $parcel->setDestination($this->destinationAddress)->getConsist();

        // sending the parcel
        $deliveryService->sendParcel($parcel);

        return true;
    }
}
